==> elisa-plugins-bad_0.5.9-1.orig.tar.gz: elisa-plugins-bad-0.5.9/elisa/plugins/poblesec/tests/test_history.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2007-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Guido Amoruso <guidonte@fluendo.com>

from twisted.trial.unittest import TestCase
from twisted.internet import defer

from elisa.core import common
from elisa.core.config import Config
from elisa.core.utils.cancellable_defer import CancelledError

from elisa.plugins.pigment.pigment_frontend import PigmentFrontend
from elisa.plugins.pigment.pigment_frontend import ControllerNotFound
from elisa.plugins.pigment.pigment_controller import PigmentController

from elisa.plugins.poblesec.history import History


class FakeController(PigmentController):
    pass

class BadControllerError(Exception):
     pass

class BadController(PigmentController):
    def __init__(self):
        super(BadController, self).__init__()
        raise BadControllerError

class NeverEndingController(PigmentController):
    def initialize(self):
        return defer.Deferred()

class FakeApplication(object):
    config = Config()

    def __init__(self):
        self.log_failure_called = False

    def log_failure(self, failure):
        self.log_failure_called = True

class TestHistory(TestCase):

    def setUp(self):
        common.set_application(FakeApplication())
        frontend = PigmentFrontend()
        self.history = History(frontend)

    def test_append_controller_error(self):
        dfr = self.history.append_controller("/fake/controller", "Dummy")
 
        self.failUnlessFailure(dfr, ControllerNotFound)
        self.failUnlessIdentical(self.history.current, None)
        self.failUnlessEqual(self.history.index, -1)
        self.failUnlessEqual(self.history._controllers, [])
        #self.failUnlessEqual(self.history._creation_dfr, None)
        self.failUnless(common.application.log_failure_called)
        return dfr

    def test_append_controller_error_creating(self):
        self.history.frontend.add_controller("/bad/controller", BadController)
        dfr = self.history.append_controller("/bad/controller", "Bad")

        self.failUnlessFailure(dfr, BadControllerError)
        self.failUnlessIdentical(self.history.current, None)
        self.failUnlessEqual(self.history.index, -1)
        self.failUnlessEqual(self.history._controllers, [])
        #self.failUnlessEqual(self.history._creation_dfr, None)
        self.failUnless(common.application.log_failure_called)
        return dfr

    def test_append_controller_success(self):
        self.history.frontend.add_controller("/fake/controller", FakeController)

        dfr = self.history.append_controller("/fake/controller", "Dummy")

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(self.history._controllers, [result])
            self.failUnlessEqual(len(self.history._controllers), 1)
            self.failUnlessEqual(self.history._creation_dfr.result, result)

        dfr.addCallback(checks)

        return dfr

    def _append_controllers(self):
        self.history.frontend.add_controller("/fake/controller", FakeController)
        self.history.frontend.add_controller("/dummy/controller", FakeController)

        dfr = self.history.append_controller("/fake/controller", "Fake")
        dfr.addCallback(lambda res: self.history.append_controller("/dummy/controller", "Dummy"))
        dfr.addCallback(lambda res: self.history.append_controller("/dummy/controller", "Dummy"))

        return dfr

    def test_append_controller_many(self):
        dfr = self._append_controllers()

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 2)
            self.failUnlessEqual(self.history._controllers[-1], result)
            self.failUnlessEqual(len(self.history._controllers), 3)
            #self.failUnlessEqual(self.history._creation_dfr.result, result)

        dfr.addCallback(checks)

        return dfr

    def test_append_controller_cancel(self):
        self.history.frontend.add_controller("/neverending/controller", NeverEndingController)
        self.history.frontend.add_controller("/fake/controller", FakeController)

        def on_cancel(*args):
            """catching the cancellation"""
            pass

        dfr = self.history.append_controller("/neverending/controller", "NeverEnding")
        dfr.addErrback(on_cancel)
        dfr = self.history.append_controller("/fake/controller", "Fake")

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(self.history._controllers, [result])
            self.failUnlessEqual(len(self.history._controllers), 1)
            self.failUnlessEqual(self.history._creation_dfr.result, result)

        dfr.addCallback(checks)

        return dfr

    def test_go_back(self):
        dfr = self._append_controllers()

        def checks(result):
            self.failUnlessIdentical(self.history.current, self.history._controllers[-1])

            previous = self.history._controllers[-2]
            self.history.go_back()

            self.failUnlessIdentical(self.history.current, previous)
            self.failUnlessEqual(self.history.index, 1)
            self.failUnlessEqual(len(self.history._controllers), 2)

            self.history.go_back()
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(len(self.history._controllers), 1)

            self.history.go_back()
            self.failUnlessEqual(self.history.index, -1)
            self.failUnlessEqual(len(self.history._controllers), 0)

        dfr.addCallback(checks)

        return dfr

    def test_go_back_cancel(self):
        self.history.frontend.add_controller("/neverending/controller", NeverEndingController)
        self.history.frontend.add_controller("/fake/controller", FakeController)

        def on_cancel(*args):
            """catching the cancellation"""
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(len(self.history._controllers), 1)

        dfr = self.history.append_controller("/fake/controller", "Fake")
        dfr.addCallback(lambda res: self.history.append_controller("/neverending/controller", "NeverEnding"))
        dfr.addErrback(on_cancel)

        self.history.go_back()

        return dfr

    def test_go_back_void(self):
        self.history.go_back()

    def test_go_back_broken_current(self):
        self.history.current = "Hijacked"
        self.history.go_back()

==> elisa-plugins-bad_0.5.15.5.orig.tar.gz: elisa-plugins-bad-0.5.15.5/elisa/plugins/poblesec/tests/test_history.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2007-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Guido Amoruso <guidonte@fluendo.com>

from twisted.trial.unittest import TestCase
from elisa.core.utils import defer

from elisa.core import common
from elisa.core.config import Config
from elisa.core.utils.cancellable_defer import CancelledError

from elisa.plugins.pigment.pigment_frontend import PigmentFrontend
from elisa.plugins.pigment.pigment_frontend import ControllerNotFound
from elisa.plugins.pigment.pigment_controller import PigmentController

from elisa.plugins.poblesec.history import History


class FakeController(PigmentController):
    pass

class BadControllerError(Exception):
     pass

class BadController(PigmentController):
    def __init__(self):
        super(BadController, self).__init__()
        raise BadControllerError

class NeverEndingController(PigmentController):
    def initialize(self):
        return defer.Deferred()

class FakeApplication(object):
    config = Config()

    def __init__(self):
        self.log_failure_called = False

    def log_failure(self, failure):
        self.log_failure_called = True

class TestHistory(TestCase):

    def setUp(self):
        common.set_application(FakeApplication())
        frontend = PigmentFrontend()
        self.history = History(frontend)

    def test_append_controller_error(self):
        dfr = self.history.append_controller("/fake/controller", "Dummy")
 
        self.failUnlessFailure(dfr, ControllerNotFound)
        self.failUnlessIdentical(self.history.current, None)
        self.failUnlessEqual(self.history.index, -1)
        self.failUnlessEqual(self.history._controllers, [])
        self.failUnless(common.application.log_failure_called)
        return dfr

    def test_append_controller_error_creating(self):
        self.history.frontend.add_controller("/bad/controller", BadController)
        dfr = self.history.append_controller("/bad/controller", "Bad")

        self.failUnlessFailure(dfr, BadControllerError)
        self.failUnlessIdentical(self.history.current, None)
        self.failUnlessEqual(self.history.index, -1)
        self.failUnlessEqual(self.history._controllers, [])
        self.failUnless(common.application.log_failure_called)
        return dfr

    def test_append_controller_success(self):
        self.history.frontend.add_controller("/fake/controller", FakeController)

        dfr = self.history.append_controller("/fake/controller", "Dummy")

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(self.history._controllers, [result])
            self.failUnlessEqual(len(self.history._controllers), 1)

        dfr.addCallback(checks)

        return dfr

    def _append_controllers(self):
        self.history.frontend.add_controller("/fake/controller", FakeController)
        self.history.frontend.add_controller("/dummy/controller", FakeController)

        dfr = self.history.append_controller("/fake/controller", "Fake")
        dfr.addCallback(lambda res: self.history.append_controller("/dummy/controller", "Dummy"))
        dfr.addCallback(lambda res: self.history.append_controller("/dummy/controller", "Dummy"))

        return dfr

    def test_append_controller_many(self):
        dfr = self._append_controllers()

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 2)
            self.failUnlessEqual(self.history._controllers[-1], result)
            self.failUnlessEqual(len(self.history._controllers), 3)

        dfr.addCallback(checks)

        return dfr

    def test_append_controller_cancel(self):
        self.history.frontend.add_controller("/neverending/controller", NeverEndingController)
        self.history.frontend.add_controller("/fake/controller", FakeController)

        dfr = self.history.append_controller("/neverending/controller", "NeverEnding")

        dfr = self.history.append_controller("/fake/controller", "Fake")

        def checks(result):
            self.failUnlessIdentical(self.history.current, result)
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(self.history._controllers, [result])
            self.failUnlessEqual(len(self.history._controllers), 1)

        dfr.addCallback(checks)

        return dfr

    def test_go_back(self):
        dfr = self._append_controllers()

        def checks(result):
            self.failUnlessIdentical(self.history.current, self.history._controllers[-1])

            previous = self.history._controllers[-2]
            self.history.go_back()

            self.failUnlessIdentical(self.history.current, previous)
            self.failUnlessEqual(self.history.index, 1)
            self.failUnlessEqual(len(self.history._controllers), 2)

            self.history.go_back()
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(len(self.history._controllers), 1)

            self.history.go_back()
            self.failUnlessEqual(self.history.index, -1)
            self.failUnlessEqual(len(self.history._controllers), 0)

        dfr.addCallback(checks)

        return dfr

    def test_go_back_cancel(self):
        self.history.frontend.add_controller("/neverending/controller", NeverEndingController)
        self.history.frontend.add_controller("/fake/controller", FakeController)

        def on_cancel(*args):
            """catching the cancellation"""
            self.failUnlessEqual(self.history.index, 0)
            self.failUnlessEqual(len(self.history._controllers), 1)

        def next_append(res):
            path = "/neverending/controller"
            name = "NeverEnding"
            return self.history.append_controller(path, name)
            

        dfr = self.history.append_controller("/fake/controller", "Fake")
        dfr.addCallback(next_append)
        dfr.addErrback(on_cancel)

        self.history.go_back()

        return dfr

    def test_go_back_void(self):
        self.history.go_back()

    def test_go_back_broken_current(self):
        self.history.current = "Hijacked"
        self.history.go_back()
